@@ -3,9 +3,9 @@ package com.sun.tools.jdeps.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "18.0.2+9" },
-            { "jdk", "18.0.2" },
-            { "release", "18.0.2" },
+            { "full", "21.0.6+7-LTS" },
+            { "jdk", "21.0.6" },
+            { "release", "21.0.6" },
         };
     }
 }
